@@ -6,19 +6,27 @@ from .registry import services
 from .exceptions import NotRecognizedServiceError
 from .config import options, CONF_PATH, CACHE_FILE
 from ._cache import Cache
-from . import in_virtual
 
 
 if CONF_PATH:
+    DEFAULT_CACHE = os.path.join(CONF_PATH, CACHE_FILE)
     writable = os.access(CONF_PATH, os.W_OK)
-    DEFAULT_CACHE = os.path.join(CONF_PATH, CACHE_FILE) if writable else 'no'
 else:           # pragma: no cover
-    if in_virtual():
-        # This default cache location only makes sense for virtalenv installs
-        DEFAULT_CACHE = os.path.join(os.path.dirname(
-            os.path.abspath(__file__)), CACHE_FILE)
-    else:
-        DEFAULT_CACHE = 'no'
+    try:
+        # try write conf for the next time!
+        from .contrib._hook import mk_conf
+        mk_conf()
+    except:
+        pass
+    # only useful for development
+    DEFAULT_CACHE = os.path.join(os.path.dirname(
+        os.path.abspath(__file__)), CACHE_FILE)
+    try:
+        writable = os.access(DEFAULT_CACHE, os.W_OK)
+    except:
+        writable = False
+
+DEFAULT_CACHE = DEFAULT_CACHE if writable else 'no'
 CACHE = options.get('CACHE', DEFAULT_CACHE)
 CACHE = None if CACHE.lower() == 'no' else CACHE
 
@@ -27,7 +35,7 @@ def query(isbn, service='default', cache=CACHE):
     """Query worldcat.org, Google Books (JSON API), ... for metadata."""
     if service != 'default' and service not in services:
         raise NotRecognizedServiceError(service)
-    if not cache:
+    if cache is None:
         return services[service](isbn)
     kache = Cache() if cache == 'default' else Cache(cache)
     key = isbn + service
